## Rebuild options:
# --with hal : Build with the hal support (default: without)
#
## To rebuild this package with hal support:
# rpmbuild -ba emelfm2.spec --with hal

Name:           emelfm2
Version:        0.4.1
Release:        1%{?dist}
Summary:        A file manager that implements the popular two-pane design

Group:          Applications/File
License:        GPLv3+
URL:            http://emelfm2.net/
Source0:        http://emelfm2.net/rel/%{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  gtk2-devel >= 2.6.0, libacl-devel, gettext, desktop-file-utils
Requires:       findutils >= 4.2, file, grep, sed, bzip2
%if 0%{?_with_hal:1}
BuildRequires:  hal-devel, dbus-glib-devel
Requires:       hal
%endif

%description
emelFM2 is the GTK+2 port of emelFM. emelFM2 is a file manager that implements 
the popular two-pane design. It features a simple GTK+2 interface, a flexible 
file typing scheme, and a built-in command line for executing commands without 
opening an xterm.


%prep
%setup -q

# fix for x86_64 libs
sed -i 's!$(PREFIX)/lib/$(TARGET)/$(LIBS)!$(PREFIX)/%{_lib}/$(TARGET)/$(LIBS)!' Makefile

# fix broken icon in emelfm2.desktop
sed -i 's!emelfm2/emelfm2_48.png!%{_datadir}/pixmaps/emelfm2/emelfm2_48.png!' docs/desktop_environment/%{name}.desktop


%build
make %{?_smp_mflags} \
    OPTIMIZE="${RPM_OPT_FLAGS}" \
    CFLAGS="${RPM_OPT_FLAGS}" \
    PREFIX="%{_prefix}" \
    DOCS_VERSION=1 \
    WITH_TRANSPARENCY=1 \
    WITH_KERNELFAM=1 \
    USE_LATEST=1 \
    NEW_COMMAND=1 \
    %if 0%{?_with_hal:1}
      WITH_HAL=1 \
    %endif
    WITH_ACL=1


%install
rm -rf $RPM_BUILD_ROOT
make install DOCS_VERSION=1 PREFIX=$RPM_BUILD_ROOT%{_prefix}
make install_i18n DOCS_VERSION=1 PREFIX=$RPM_BUILD_ROOT%{_prefix}

%find_lang %{name}

desktop-file-install --vendor fedora                            \
        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications         \
        --add-category System                                   \
        --add-category Utility                                  \
        --delete-original                                       \
        ${RPM_BUILD_ROOT}%{_datadir}/applications/%{name}.desktop


%clean
rm -rf $RPM_BUILD_ROOT


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc docs/ACTIONS docs/CONFIGURATION docs/CREDITS docs/HACKING 
%doc docs/README docs/TODO docs/USAGE docs/WARNING 
%doc docs/help.txt docs/GPL docs/LGPL
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/fedora-%{name}.desktop
%{_datadir}/application-registry/%{name}.applications
%{_datadir}/pixmaps/%{name}
%{_mandir}/man1/emelfm2.1.gz

	
%changelog
* Tue Jul 08 2008 Christoph Wickert <fedora christoph-wickert de> - 0.4.1-1
- Update 0.4.1
- Revove hal_flags.patch (fixed upstream)
- Remove HAL support until it really works. To enable rebuild "--with hal"

* Wed Apr 02 2008 Christoph Wickert <fedora christoph-wickert de> - 0.4.0-1
- Update 0.4.0
- Enable HAL support, but dont install hal by default
- Add emelfm2-0.4-hal_flags.patch (Thanks to Uwe Helm)
- Require bzip2 for the unpack-plugin

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.3.6-2
- Autorebuild for GCC 4.3

* Sun Dec 02 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.6-1
- Update 0.3.6 with upstream's e2-0.3.6-07-12-01.patch
- Enable the ACL plugin

* Tue Aug 21 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.5-2
- Rebuild to fix SELinux issues on PPC32 and to include BuildID feature

* Sun Jul 29 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.5-1
- Update 0.3.5.

* Sat Jun 09 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.4-1
- Update 0.3.4.
- Enable support for inotify

* Wed Mar 21 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.3-1
- Update 0.3.3.

* Sat Feb 24 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.2-2
- Include upstream's e2-0.3.2-07-02-01.patch fixing some bugs.

* Fri Jan 19 2007 Christoph Wickert <fedora christoph-wickert de> - 0.3.2-1
- Update 0.3.2.
- Remove Category "Application" from emelfm2.desktop.

* Sat Dec 16 2006 Christoph Wickert <fedora christoph-wickert de> - 0.3.1-1
- Update 0.3.1.
- Remove Category "X-Fedora" from emelfm2.desktop.

* Mon Aug 28 2006 Christoph Wickert <fedora christoph-wickert de> - 0.3.0-1
- Update 0.3.

* Mon Aug 28 2006 Christoph Wickert <fedora christoph-wickert de> - 0.2.0-1
- Update 0.2.0.

* Fri Aug 11 2006 Christoph Wickert <fedora christoph-wickert de> - 0.1.8-2
- Include upstream's e2-0.1.8-06-08-09.patch to fix two serious bugs.

* Sun Aug 06 2006 Christoph Wickert <fedora christoph-wickert de> - 0.1.8-1
- Update to 0.1.8.

* Thu Apr 23 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.7-1
- Update to 0.1.7.

* Tue Mar 14 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.6-1
- Update to 0.1.6.
- Add Requires for plugins.

* Sat Feb 18 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.5-2
- Rebuild for Fedora Extras 5.

* Thu Jan 26 2006 Christoph Wickert <fedora wickert arcor de> - 0.1.5-1
- Update to 0.1.5.

* Thu Dec 29 2005 Christoph Wickert <fedora wickert arcor de> - 0.1.4-1
- Update to 0.1.4.

* Mon Nov 21 2005 Christoph Wickert <fedora wickert arcor de> - 0.1.3-2
- Removed nonexistant ROADMAP from %%doc.

* Mon Nov 21 2005 Christoph Wickert <fedora wickert arcor de> - 0.1.3-1
- Update to 0.1.3.

* Tue Sep 27 2005 Christoph Wickert <fedora wickert acror de> - 0.1.2-3
- Fix for x86_64.

* Mon Sep 26 2005 Christoph Wickert <fedora wickert acror de> - 0.1.2-2
- Removed broken-icon.patch (using sed instead).
- Removed hardcoded /usr from makefile.config-patch.
- Minor specfile changes (#168608).

* Sun Sep 18 2005 Christoph Wickert <fedora wickert acror de> - 0.1.2-1
- Update to 0.1.2.

* Sun Sep 11 2005 Christoph Wickert <fedora wickert acror de> - 0.1.1-2
- Using destop-file-install.
- Several fixes for FE.

* Sun Aug 21 2005 Christoph Wickert <fedora wickert acror de> - 0.1.1-1.fc4.cw
- Initial RPM release.
